
RepRep -- quick reports for the busy pythonista
===============================================

"RepRep" stands for Reproducible Reports. 
It is designed to make quick  hierarchical reports of experimental data.
"Reproducible" is in there because it encourages you to add the source data
to the report.

**(add image)**


**Current status:** usable, but the documentation is incomplete.

Documentation
-------------

.. container:: col1b

	* :ref:`why`
	* :ref:`tutorial`
	* :ref:`userguide`
	* :ref:`api`


Install
-------

Development happens on github: http://github.com/AndreaCensi/reprep

.. raw:: html
   :file: download.html



